@@ -12,10 +12,13 @@ from typing import Sequence
 from typing import Set
 from typing import Tuple
 
-from argcomplete import autocomplete
-
 from .util import __url_home__ as __url__
 
+try:
+    from argcomplete import autocomplete
+except ModuleNotFoundError:
+    pass
+
 
 class checker():
 
@@ -23,8 +26,7 @@ class checker():
 
     @classmethod
     def check_name_pos(cls, fn):
-        '''
-        check positional argument name
+        '''check positional argument name
         '''
 
         def inner(self, name: str, **kwargs):
@@ -36,8 +38,7 @@ class checker():
 
     @classmethod
     def check_name_opt(cls, fn):
-        '''
-        check optional argument name
+        '''check optional argument name
         '''
 
         def inner(self, *name: str, **kwargs):
@@ -54,8 +55,7 @@ class checker():
 
     @classmethod
     def check_nargs_opt(cls, fn):
-        '''
-        nargs hook function:
+        '''nargs hook function:
             nargs < -1: using "?", 0 or 1 argument, default value
             nargs = -1: using "+", arguments list, at least 1
             nargs = 0: using "*", arguments list, allow to be empty
@@ -74,8 +74,7 @@ class checker():
 
 
 class argp(ArgumentParser):
-    '''
-    Simple command-line tool based on argparse.
+    '''Simple command-line tool based on argparse.
     '''
 
     def __init__(self,
@@ -92,29 +91,37 @@ class argp(ArgumentParser):
         kwargs.setdefault("epilog", epilog)
         ArgumentParser.__init__(self, **kwargs)
         self.__argv: Optional[Sequence[str]] = argv
-        self.__help_option: Dict[str, _HelpAction] = dict()
+        self.__help_option: Dict[str, _HelpAction] = {}
         self.__prev_parser: argp = prev_parser or self
-        self.__next_parser: List[argp] = list()
+        self.__next_parser: List[argp] = []
         if prev_parser is not None:
-            prev_parser.__next_parser.append(self)
+            prev_parser.next_parser.append(self)
 
     @property
     def argv(self) -> Optional[Sequence[str]]:
-        return self.root_parser.__argv
+        root = self.root_parser
+        return root.argv if root is not self else self.__argv
+
+    @property
+    def prev_parser(self) -> "argp":
+        return self.__prev_parser
+
+    @property
+    def next_parser(self) -> List["argp"]:
+        return self.__next_parser
 
     @property
     def root_parser(self) -> "argp":
-        root = self.__prev_parser
-        while root.__prev_parser != root:
-            root = root.__prev_parser
+        root = self.prev_parser
+        while root.prev_parser != root:
+            root = root.prev_parser
         return root
 
     def argument_group(self,
                        title: Optional[str] = None,
                        description: Optional[str] = None,
                        **kwargs) -> _ArgumentGroup:
-        '''
-        Find the created argument group by title, create if not exist.
+        '''Find the created argument group by title, create if not exist.
         '''
         for group in self._action_groups:
             if title == group.title:
@@ -123,8 +130,7 @@ class argp(ArgumentParser):
 
     @checker.check_name_opt
     def filter_optional_name(self, *name: str) -> Sequence[str]:
-        '''
-        Filter defined optional argument name.
+        '''Filter defined optional argument name.
         '''
         option_strings: Set[str] = set()
         for action in self._get_optional_actions():
@@ -133,8 +139,7 @@ class argp(ArgumentParser):
 
     @checker.check_name_pos
     def add_pos(self, name: str, **kwargs) -> None:
-        '''
-        Add positional argument.
+        '''Add positional argument.
         '''
         assert "dest" not in kwargs, \
             "dest supplied twice for positional argument"
@@ -143,15 +148,13 @@ class argp(ArgumentParser):
     @checker.check_name_opt
     @checker.check_nargs_opt
     def add_opt(self, *name: str, **kwargs) -> None:
-        '''
-        Add optional argument.
+        '''Add optional argument.
         '''
         self.add_argument(*name, **kwargs)
 
     @checker.check_name_opt
     def add_opt_on(self, *name: str, **kwargs) -> None:
-        '''
-        Add boolean optional argument, default value is False.
+        '''Add boolean optional argument, default value is False.
         '''
         kwargs.update({"action": "store_true"})
         for key in ("type", "nargs", "const", "default", "choices"):
@@ -160,8 +163,7 @@ class argp(ArgumentParser):
 
     @checker.check_name_opt
     def add_opt_off(self, *name: str, **kwargs) -> None:
-        '''
-        Add boolean optional argument, default value is True.
+        '''Add boolean optional argument, default value is True.
         '''
         kwargs.update({"action": "store_false"})
         for key in ("type", "nargs", "const", "default", "choices"):
@@ -169,8 +171,7 @@ class argp(ArgumentParser):
         self.add_argument(*name, **kwargs)
 
     def add_subparsers(self, *args, **kwargs) -> _SubParsersAction:
-        '''
-        Add subparsers.
+        '''Add subparsers.
         '''
         # subparser: cannot have multiple subparser arguments
         kwargs.setdefault("title", "subcommands")
@@ -182,7 +183,10 @@ class argp(ArgumentParser):
 
     def parse_args(self, args: Optional[Sequence[str]] = None,
                    namespace: Optional[Namespace] = None) -> Namespace:
-        autocomplete(self)  # For tab completion
+        try:
+            autocomplete(self)  # For tab completion
+        except NameError:
+            pass
         return super().parse_args(args=args, namespace=namespace)
 
     def parse_known_args(self, args: Optional[Sequence[str]] = None,
@@ -205,8 +209,7 @@ class argp(ArgumentParser):
             self._option_string_actions.pop(option)
 
     def preparse_from_sys_argv(self) -> Namespace:
-        '''
-        Preparse some arguments from sys.argv for tab completion.
+        '''Preparse some arguments from sys.argv for tab completion.
 
         When arguments contain the help option, call parse_known_args()
         will print help message and exit. The command line can parse
@@ -222,12 +225,12 @@ class argp(ArgumentParser):
 
         def __dfs_enable_help_action(root: argp):
             root.__enable_help_action()
-            for _sub in root.__next_parser:
+            for _sub in root.next_parser:
                 __dfs_enable_help_action(_sub)
 
         def __dfs_disable_help_action(root: argp):
             root.__disable_help_action()
-            for _sub in root.__next_parser:
+            for _sub in root.next_parser:
                 __dfs_disable_help_action(_sub)
 
         try:
